@@ -12,17 +12,17 @@
 #
 ##############################################################################
 """
-$Id: textformatter.py 82216 2007-12-10 11:04:16Z schwendinger $
+$Id: textformatter.py 96018 2009-02-03 08:06:16Z jukart $
 """
 import re
 from zope.tales.expressions import PathExpr
 
+NO_SCRIPTS = re.compile('<\s*script[^>]+>(.*)<\s*\/script\s*>', re.I | re.DOTALL)
+NO_ESCAPED_SCRIPTS = re.compile('&lt;\s*script[^&]+.*&lt;\s*\/script\s*&gt;', re.I | re.DOTALL)
 
 class TextFormatter(PathExpr):
 
-
     def __call__(self, context):
-
         rendered = super(TextFormatter, self).__call__(context)
         return self._doFormat(rendered, context)
 
@@ -33,6 +33,15 @@ class TextFormatter(PathExpr):
 
         allowAll = ('allow-all' in context.vars)
 
+        if not 'allow-scripts' in context.vars:
+            rendered = self._stripScripts(rendered, context)
+
+        if 'clear-html' in context.vars:
+            rendered = self._clearHTML(rendered, context)
+
+        if 'cut' in context.vars:
+            rendered = self._cut(rendered, context)
+
         if 'replace' in context.vars:
             rendered = self._replace(rendered, context)
 
@@ -48,8 +57,8 @@ class TextFormatter(PathExpr):
         if 'break-string' in context.vars:
             rendered = self._breakString(rendered, context)
 
-        if 'cut' in context.vars:
-            rendered = self._cut(rendered, context)
+        if 'urlparse' in context.vars:
+            rendered = self._urlparse(rendered, context)
 
         return rendered
 
@@ -84,7 +93,6 @@ class TextFormatter(PathExpr):
 
 
             #find tags with no closing tag like <input type="submit" value="bla" />
-            reg = re.compile('<%s[^>]*/>' %al, re.VERBOSE)
             found = reg.findall(rendered)
             for f in found:
                 f_rep = f.replace('<', '__LOWER__')
@@ -136,11 +144,17 @@ class TextFormatter(PathExpr):
         realText = realText[:position] + expr + realText[position:]
         return realText
 
+    def _clearHTML(self, rendered, context):
+        # remove tags
+        return re.sub('<.*?>', '', rendered)
+
     def _cut(self, rendered, context):
         cut = context.vars['cut']
         if len(rendered) <= cut:
             return rendered
         rendered = rendered[:cut]
+        if 'softcut' in context.vars:
+            rendered = rendered.rsplit(' ', 1)[0]
         if 'attach' in context.vars:
             rendered = self._attach(rendered, context)
         return rendered
@@ -151,3 +165,53 @@ class TextFormatter(PathExpr):
             return rendered + attach
         return rendered
 
+    def _stripScripts(self, rendered, context):
+        rendered = re.sub(NO_SCRIPTS, '', rendered)
+        rendered = re.sub(NO_ESCAPED_SCRIPTS, '', rendered)
+        return rendered
+
+    def _urlparse(self, rendered, context):
+        #searches for urls coded with www. or http:
+
+        vars = context.vars['urlparse']
+        parameters=""
+
+        if vars:
+            for k, v in vars.items():
+                parameters +='%s="%s" ' % (k, v)
+        else:
+            parameters ='rel="nofollow" target="_blank"'
+
+        search = re.compile(
+               '(((<a\s*href\s*=\s*")?|(\s*src\s*=\s*")?)'\
+               '(http:\\/\\/|www)[-A-Za-z0-9]*\\.[-A-Za-z0-9\\.]+'\
+               '(~/|/|\\./)?([-A-Za-z0-9_\\$\\.\\+\\!\\*\\(\\),;:'\
+               '@&=\\?/~\\#\\%]+|\\\\ )+"?)'
+                )
+
+        results = search.findall(rendered)
+        searchLink = re.compile('^(<a\s*href\s*=\s*")')
+
+
+        for url in results:
+            if url[1] == '':
+                newurl = ' <a href="%s%s" %s>%s</a> ' % (
+                        'http://', 
+                        url[0].lstrip(), 
+                        parameters.rstrip(), 
+                        url[0].lstrip())
+
+                if url[4] == "http://":
+                    newurl = '<a href="%s" %s>%s</a>' % (
+                            url[0], 
+                            parameters.rstrip(), 
+                            url[0])
+
+                rendered = rendered.replace(url[0],newurl)
+
+            if searchLink.search(url[1]) and parameters !="":
+                link = '%s %s' % (url[0], parameters.rstrip())
+                rendered = rendered.replace(url[0],link)
+
+        return rendered
+
